package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!`````"8```````!``````````#BQ````
M`````````$``.``+`$``&P`:``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````#`:````````,!H`````````
M$`````````$````%`````"``````````(``````````@````````%3P`````
M```5/``````````0`````````0````0`````8`````````!@`````````&``
M```````81@```````!A&`````````!`````````!````!@```+"K````````
ML+L```````"PNP```````'`$````````&!4`````````$`````````(````&
M````P*L```````#`NP```````,"[````````$`(````````0`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````%"?````````4)\```````!0GP``
M`````.P`````````[``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``"PJP```````+"[````````L+L```````!0!````````%`$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`"J+6=7TD)EMJ&_C1:FCEQ;#?%LH!````!`````!````1TY5```````#
M`````@`````````1````0P````0````(````(!P0``5`!(8H`D``D(8`@(()
M`"!)(`0(N*(11;H``@H`````0P```$8```!)````2@```%````!1````4P``
M`%<```!8`````````%H```!=````7P```&```````````````&[%WQ_.WD<M
M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\#"Y3\LNN.2?/NA;&!K
M"4/69J_,9L6YG$`X\HL<Q(D%D$)%U>R)!W#3#13BGC)BV^W;S>.>##J7"U:D
MFY:GW:-K?JF<F]%ESFWAIP(*"HH05Z/@^TD`````````````````````````
M``````#W`0``$@`````````````````````````,`0``$@``````````````
M``````````"3````$@````````````````````````"6`@``$@``````````
M``````````````#,`0``$@````````````````````````"3`0``$@``````
M``````````````````!1`@``$@````````````````````````"!`@``$@``
M```````````````````````B`0``$@`````````````````````````1````
M(``````````````````````````5`@``$@````````````````````````!%
M`P``$@````````````````````````#:`0``$@``````````````````````
M```:`@``$@````````````````````````"J`0``$@``````````````````
M```````I`P``$@````````````````````````!3`0``$@``````````````
M``````````"T````$@````````````````````````!#`0``$@``````````
M```````````````\`@``$@````````````````````````![`@``$@``````
M```````````````````U`0``$@````````````````````````#8`@``$@``
M``````````````````````!8`@``$@````````````````````````#=`P``
M$@`````````````````````````@````(`````````````````````````"Q
M`0``$@`````````````````````````1`0``$@``````````````````````
M``!M`@``$@`````````````````````````\````(```````````````````
M``````"O`@``$@````````````````````````!6````$@``````````````
M``````````"#`0``$@````````````````````````!S````$@``````````
M``````````````#P````$@````````````````````````"$````$@``````
M``````````````````#?`0``$@````````````````````````!T`@``$@``
M``````````````````````#4````$@````````````````````````#/`@``
M$@````````````````````````!U`0``$@`````````````````````````3
M`P``$@````````````````````````#E`@``$@``````````````````````
M``"D`@``$@````````````````````````!G`0``$@``````````````````
M``````#F`0``$@````````````````````````!?`@``$@``````````````
M```````````6`0``$@`````````````````````````K`@``$@``````````
M```````````````B`P``$@````````````````````````!F`@``$@``````
M``````````````````#(`@``$@````````````````````````"?````$@``
M``````````````````````"W`@``$@````````````````````````">`0``
M$@````````````````````````#2`0``$@`````````````````````````B
M`@``$@`````````````````````````%`P``$@``````````````````````
M```;`P``$@````````````````````````!)`@``$@``````````````````
M``````!<`0``$@````````````````````````!D````$@``````````````
M``````````"/`@``$@````````````````````````#L`@``$@``````````
M``````````````!#`@``$@````````````````````````#"````$@``````
M``````````````````#F`P``$@`.`!!;````````=P`````````W!```$@`.
M`/!+````````.`L````````V`P``$@`.`/`C````````!`(```````!7`P``
M$@`.`(!%````````!0````````"%`P``$@`.`#!7````````V0,```````!=
M!```$@`.`)!%````````\@$````````F!```$``8`"#`````````````````
M``!H`P``$@`.`)!'````````)0````````";`P``$@`.`'!*````````=```
M``````#R`P``$0`0``!@````````!``````````.!```$@`.`$!$````````
M,``````````R!```$``8`,C0``````````````````!+!```$@`.`!!+````
M````W@`````````!!```$``7``#```````````````````"_`P``$@`.`,!'
M````````W``````````[`P``$0`8`$#`````````"`````````#!`@``$0`8
M`&#`````````"``````````\`P``(0`8`$#`````````"`````````!$!```
M$``7`"#```````````````````!J!```$0`7`!C`````````"`````````!U
M`P``$@`.`/!;`````````0`````````'!```$@`.```F````````*P``````
M```6!```$@`.`)!;````````70`````````#!```(``7``#`````````````
M```````!`0``$0`8`"#`````````!``````````]`P``(0`8`$#`````````
M"`````````#+`P``$@`.`/!*````````'0````````#V`@``(@``````````
M``````````````"I`P``$@`.`,!$````````OP````````#C````$0`8`(#`
M`````````0````````!T!```$@`.`*!(````````S@$`````````;&EB<&5R
M;"YS;RXU+C,P`%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO
M;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L:6)P=&AR96%D+G-O
M+C``8VQO<V4`;'-E96LV-`!R96%D`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N
M`'!T:')E861?9V5T<W!E8VEF:6,`;&EB8RYS;RXV`&5X:70`<W1R;F-M<`!C
M;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C
M`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M
M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T
M870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK
M`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE
M`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S
M=&%R=%]M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!P87)?8W5R
M<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!X<U]I
M;FET`%]?;&EB8U]C<W5?:6YI=`!?7V)S<U]S=&%R=`!?96YD`'!A<E]M:W1M
M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY
M7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ-`!'3$E"0U\R+C0`1TQ)
M0D-?,BXS+C(`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXS+C0````"```````#``(`
M```$``,```````0`!0`"``0`!``$``````````0`!`````,`!``$```````$
M``0````$```````````````"``0````$````!``$``0````"``0````&``0`
M!``$````!`````(`!``#``0`!```````!P`$``0````!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`$``0`!``!``$``0`!``$``0````0``0`$``$`
M```!`````0`%``L"```0````8````)21E@8```<`@00``!`````4:6D-```&
M`(P$```0````<AEI"0``!0"6!```$````'4::0D```0`H@0``!````!T&6D)
M```#`*X$`````````0`!`+P!```0`````````'4::0D```(`H@0```````"P
MNP````````@`````````X"8```````"XNP````````@`````````H"8`````
M```(P`````````@`````````",`````````8P`````````@`````````Z&(`
M``````#`OP````````8````)``````````````#(OP````````8````*````
M``````````#0OP````````8````0``````````````#8OP````````8````:
M``````````````#@OP````````8````>``````````````#HOP````````8`
M``!>``````````````#POP````````8````A``````````````#XOP``````
M``8````B```````````````@P`````````4```!;``````````````!`P```
M``````4```!2``````````````!@P`````````4```!3``````````````"`
MP`````````4```!@``````````````#HO0````````<````!````````````
M``#PO0````````<````"``````````````#XO0````````<````#````````
M````````O@````````<````$```````````````(O@````````<````%````
M```````````0O@````````<````&```````````````8O@````````<````'
M```````````````@O@````````<````(```````````````HO@````````<`
M```+```````````````PO@````````<````,```````````````XO@``````
M``<````-``````````````!`O@````````<````.``````````````!(O@``
M``````<````/``````````````!0O@````````<````1``````````````!8
MO@````````<````2``````````````!@O@````````<````3````````````
M``!HO@````````<````4``````````````!PO@````````<````5````````
M``````!XO@````````<````6``````````````"`O@````````<````7````
M``````````"(O@````````<````8``````````````"0O@````````<````9
M``````````````"8O@````````<````;``````````````"@O@````````<`
M```<``````````````"HO@````````<````=``````````````"PO@``````
M``<````?``````````````"XO@````````<````@``````````````#`O@``
M``````<````C``````````````#(O@````````<````D``````````````#0
MO@````````<````E``````````````#8O@````````<````F````````````
M``#@O@````````<````G``````````````#HO@````````<````H````````
M``````#PO@````````<````I``````````````#XO@````````<````J````
M````````````OP````````<````K```````````````(OP````````<````L
M```````````````0OP````````<````M```````````````8OP````````<`
M```N```````````````@OP````````<````O```````````````HOP``````
M``<````P```````````````POP````````<````Q```````````````XOP``
M``````<````R``````````````!`OP````````<````S``````````````!(
MOP````````<````T``````````````!0OP````````<````U````````````
M``!8OP````````<````V``````````````!@OP````````<````W````````
M``````!HOP````````<````X``````````````!POP````````<````Y````
M``````````!XOP````````<````Z``````````````"`OP````````<````[
M``````````````"(OP````````<````\``````````````"0OP````````<`
M```]``````````````"8OP````````<````^``````````````"@OP``````
M``<````_``````````````"HOP````````<```!```````````````"POP``
M``````<```!!``````````````"XOP````````<```!"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%O9\``$B%P'0"_]!(@\0(PP```````````/\ULIT``/\EM)T`
M``\?0`#_);*=``!H`````.G@_____R6JG0``:`$```#IT/____\EHIT``&@"
M````Z<#_____)9J=``!H`P```.FP_____R62G0``:`0```#IH/____\EBIT`
M`&@%````Z9#_____)8*=``!H!@```.F`_____R5ZG0``:`<```#I</____\E
M<IT``&@(````Z6#_____)6J=``!H"0```.E0_____R5BG0``:`H```#I0/__
M__\E6IT``&@+````Z3#_____)5*=``!H#````.D@_____R5*G0``:`T```#I
M$/____\E0IT``&@.````Z0#_____)3J=``!H#P```.GP_O___R4RG0``:!``
M``#IX/[___\E*IT``&@1````Z=#^____)2*=``!H$@```.G`_O___R4:G0``
M:!,```#IL/[___\E$IT``&@4````Z:#^____)0J=``!H%0```.F0_O___R4"
MG0``:!8```#I@/[___\E^IP``&@7````Z7#^____)?*<``!H&````.E@_O__
M_R7JG```:!D```#I4/[___\EXIP``&@:````Z4#^____)=J<``!H&P```.DP
M_O___R72G```:!P```#I(/[___\ERIP``&@=````Z1#^____)<*<``!H'@``
M`.D`_O___R6ZG```:!\```#I\/W___\ELIP``&@@````Z>#]____):J<``!H
M(0```.G0_?___R6BG```:"(```#IP/W___\EFIP``&@C````Z;#]____)9*<
M``!H)````.F@_?___R6*G```:"4```#ID/W___\E@IP``&@F````Z8#]____
M)7J<``!H)P```.EP_?___R5RG```:"@```#I8/W___\E:IP``&@I````Z5#]
M____)6*<``!H*@```.E`_?___R5:G```:"L```#I,/W___\E4IP``&@L````
MZ2#]____)4J<``!H+0```.D0_?___R5"G```:"X```#I`/W___\E.IP``&@O
M````Z?#\____)3*<``!H,````.G@_/___R4JG```:#$```#IT/S___\E(IP`
M`&@R````Z<#\____)1J<``!H,P```.FP_/___R42G```:#0```#IH/S___\E
M"IP``&@U````Z9#\____)0*<``!H-@```.F`_/___R7ZFP``:#<```#I</S_
M__\E\IL``&@X````Z6#\____)>J;``!H.0```.E0_/___R7BFP``:#H```#I
M0/S___\E`IP``&:0``````````!!5%5(@^PXB7PD'$B-?"0<2(ET)!!(C70D
M$$B)5"0(2(U4)`AD2(L$)2@```!(B40D*#'`Z&?___](BS60FP``2(L]P9L`
M`$B)\NC!-P``@#TZG````'4OZ$/]__](B05LK```2(G'2(7`#X2*`0``Z(O]
M__^+/;6;``#HP/O__\:`T0D```"+/:.;``#HKOO__XL]F)L``("(.@0```+H
MG/O__X"(.@0```&+1"0<C7@%2&/_2,'G`^AR_O__3(M,)!"+5"0<QP7OJP``
M!````$B)P4B)!=VK``!)BP%(B0%(C07\/```2(E!"$B+!36;``!(B4$02(T%
MZ3P``$B)01B#^@%^*42-0OZ^`0```$F#P`(/'T``28L$\8U^!$B#Q@%(8_](
MB43Y^$DY\'7HC4($13'`@\(#2(L]D*L``$B82(TU-Q\``$C'1,'X`````.@Y
M^___08G$A<!T4TB+/6NK``!(C6PD).@A_?__,<!(B>Y(C3TY.P``Z%`8``!(
MA<!T/4B+/42K``#HO_K__^A*_/__2(M$)"AD2#,$)2@```!U3TB#Q#A$B>!=
M05S#2(L]&*L``.A3^___08G$ZYQ(BSW_J@``2(7_=`?H334``.NP2(T]C3H`
M`$B)[NCL%P``2(D%W:H``$B)QTB%P'22Z]GHUOS__[\!````Z+SZ__]F+@\?
MA```````9I`Q[4F)T5Y(B>)(@^3P4%1,C07:-0``2(T-<S4``$B-/<S]____
M%::9``#T#Q]$``!(C3WIF0``2(T%XID``$@Y^'052(L%CID``$B%P'0)_^`/
M'X``````PP\?@`````!(C3VYF0``2(TULID``$@I_DB)\$C![C](P?@#2`'&
M2-'^=!1(BP55F0``2(7`=`C_X&8/'T0``,,/'X``````@#W:F0```'4O54B#
M/3:9````2(GE=`Q(BSU*F0``Z!W]___H:/___\8%LID```%=PP\?@`````##
M#Q^``````.E[____9BX/'X0``````)!!5TR-3SA!5D%505154TB![)@"``!D
M2(L$)2@```!(B80DB`(``#'`2(GB3(V4)(````!)B=!F+@\?A```````08L!
M28LQ28/`$$F#P0@/R(G`2(GQ28E`\$B)\$C!Z2!(P>@H2,'N."4`_P``2`GP
M2(G.2,'A"$C!YAB!X0``_P")]D@)\$@)R$F)0/A-.=!UKDB-L@`"```/'X``
M````2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@_TB)0GA(.?)U
MU4R+!TR+3Q!(BU\@3(M7&$R)P$R)PDB+="0(3(MT)!A(P>H;2,'@!4@)T`,$
M)$F-K#*9>8):C908F7F"6DR)R$R)PTPQT$@C1PA(P>,>3#'01(TD`DB+5PA(
MBT<(3(GF2,'B'DC!Z`)("=!,B<I(P>X;B<%(,<I,(<),,<I(`>I,B>5(P>4%
M2`GU2`'53(G"2,'J`D&)[4@)TTB+5"002#'808G;3"'@28V4$9EY@EI(,<A*
MC8PQF7F"6DB--!!(B>I(P>T;2+C@____'P```$C!X@6#Y1]((<)(">I(`?),
MB>9)P>P"2,'F'HG53`GF2#'S08GT3"'K3#';2`'+2(G12,'J&TC!X06#XA](
M(<%("<I,B>E)P>T"2,'A'D@!VDP)Z4R+;"0@B=-(,<Y!B<Y((>Y/C9PKF7F"
M6DPQYDP!WDF)TTC!ZAM)P>,%@^(?22'#20G32(M4)"A)`?-(B>Y(P>T"2,'F
M'DF-E!29>8):18G=2`GN2#'QB?5((=E,,?%(`<I,B=E(P>$%2"'!2<'K&T&#
MXQ],"=E,BUPD,$@!T4B)VDC!ZP)(P>(>3XV<'IEY@EI!B<Q("=I(,=:)TTPA
M[D@Q[DD!\TB)SDC!Z1M(P>8%@^$?2"'&2`G.2(M,)#A,`=Y-B>M)P>T"2<'C
M'DB-C`V9>8):08GV30GK3#':18G=3"'B2#':2`'12(GR2,'N&TC!X@6#YA](
M(<)("?)(BW0D0$@!RDR)X4C!X1Y)P>P"2(VT,YEY@EJ)U4P)X4DQRT&)S$TA
M\TTQZTP!WDF)TTC!ZAM)P>,%@^(?22'#20G32(M4)$A)`?-,B?9)P>X"2,'F
M'DF-E!69>8):1(G;3`GV2#'Q08GV2"'I3#'A2`'*3(G92<'K&TC!X05!@^,?
M2"'!3`G93(M<)%!(`=%(B>I(P>T"2,'B'D^-G!R9>8):08G-2`GJ2#'6B=5(
M(=Y,,?9)`?-(B<Y(P>8%2,'I&T@AQH/A'T@)SDB+3"183`'>28G;2,'K`DG!
MXQY)C8P.F7F"6D&)]$D)VTPQVD2)VTPAZD@QZD@!T4B)\DC![AM(P>(%@^8?
M2"'"2`GR2(MT)&!(`<I,B>E)P>T"2,'A'DB-M#69>8):08G63`GI23'+08G-
M32'C23';3`'>28G32,'J&TG!XP6#XA])(<-)"=-(BU0D:$D!\TR)YDC!YAY)
MP>P"2(V4$YEY@EI$B=U,">9(,?%!B?1,(?%,,>E(`<I,B=E)P>L;2,'A!4&#
MXQ]((<%,"=E,BUPD<$@!T4R)\DG![@)(P>(>3XV<'9EY@EJ)RTP)\D@QUD&)
MUD@A[DPQYDD!\TB)SDC!Z1M(P>8%@^$?2"'&2`G.2(M,)'A,`=Y)B>M(P>T"
M2<'C'DF-C`R9>8):08GU20GK3#':1(G=2"':3#'R2`'12(GR2,'N&TC!X@6#
MYA]((<)("?)(B[0D@````$@!RDB)V4C!ZP)(P>$>28VT-IEY@EI!B=1("=E)
M,<N)RTTAZTDQZTP!WDF)TTC!ZAM)P>,%@^(?22'#20G32(N4)(@```!)`?-,
MB>Y)P>T"2,'F'DB-E!69>8):18G>3`GN2#'Q08GU3"'A2#'92`'*3(G92<'K
M&TC!X05!@^,?2"'!3`G92`'13(GB2<'L`DC!XAZ)S4P)XDR+I"20````2#'6
M08G33"'V2HV<(YEY@EI,,>Y(`=Y(B<M(P>D;2,'C!8/A'T@APT@)V4R)\TG!
M[@)(P>,>B<E,"?-(`<Y(BXPDF````$@QVD&)]$@AZDF-C`V9>8):38GE3#':
M2<'M&T@!RDR)X4C!X05,">F)R4@!RDB)Z4C![0)(P>$>08G52`GI2(G=B=M(
M,<TQ[DB+K"2@````38V<*Z'KV6Y,B>U)`?-,B>Y(P>8%2,'M&T@#G"2H````
M2`GNB?9,`=Y-B>-)P>P"2<'C'HGU30GC28G,B<E(`XPDL````$TQW$0QXDR-
MI!.AZ]EN2(GJ2(GK2,'K&TC!X@5("=J)TDF-'!1,B>I)P>T"2,'B'D&)W$P)
MZDV)W46)VTP#G"2X````23'51#'N38GE2(VT,:'KV6Y,B>%)P>T;2,'A!4P)
MZ8G)2`'Q2(GN2,'M`DC!YAY!B<U(">Y(B=6)TD@Q]3'K3(GM28V<&Z'KV6Y-
MB>M(P>T;2<'C!4D)ZT6)VTD!VTR)XTC!XQY)P>P"1(G=2`.4),````!,">-)
MB?2)]D@#M"3(````23'<1#'A28GL2(V,"J'KV6Y(B>I)P>P;2,'B!4P)XHG2
M2`'*3(GI2<'M`DC!X1Y!B=1,">E)B=V)VT@#G"30````23'-13'K38GE3HV<
M'J'KV6Y,B>9)P>T;2,'F!4P)[HGV3`'>28GK2,'M`DG!XQY!B?5)">M(B<V)
MR4PQW3'J2(VL$Z'KV6Y,B>I,B>M(P>L;2,'B!4@)VHG22(U<%0!,B>))P>P"
M2,'B'HG=3`GB38G<2`.,)-@```!%B=M),=1,`YPDX````$0QYDF)[$B-M#&A
MZ]EN2(GI2<'L&TC!X05,">&)R4@!\4R)[DG![0)(P>8>08G,3`GN28G5B=)(
M`Y0DZ````$DQ]40QZTV)Y4F-G!NAZ]EN38GC2<'M&TG!XP5-">M%B=M)`=M(
MB>M(P>T"2,'C'D6)W4@)ZTB)]8GV2`.T)/````!(,=TQZ4R)[4B-C`JAZ]EN
M3(GJ2,'M&TC!X@5(">J)TD@!RDR)X4G![`)(P>$>B=5,">%)B=R)VTDQS$4Q
MXTF)[$@#G"3X````3HV<'J'KV6Y(B>Y)P>P;2,'F!4P)YHGV3`'>38GK2<'M
M`DG!XQY!B?1-">M)B<V)R4@#C"0``0``33'=1#'J3(VL$Z'KV6Y,B>),B>-(
MP>L;2,'B!4@)VHG228U<%0!(B>I(P>T"2,'B'D&)W4@)ZDR)W46)VTP#G"0(
M`0``2#'5,>Y,B>U(C;0QH>O9;DR)Z4C![1M(P>$%2`GIB<E(`?%,B>9)P>P"
M2,'F'HG-3`GF28G4B=)),?1$,>-)B>Q)C9P;H>O9;DF)ZTG![!M)P>,%30GC
M2`.4)!`!``!%B=M)`=M,B>M)P>T"2,'C'D6)W$P)ZTF)]8GV2`.T)!@!``!)
M,=U$,>E-B>5(C8P*H>O9;DR)XDG![1M(P>(%3`GJB=)(`<I(B>E(P>T"2,'A
M'D&)U4@)Z4B)W8G;2`.<)"`!``!(,<U!,>M,B>U.C9P>H>O9;DR)[DC![1M(
MP>8%2`GNB?9,`=Y-B>-)P>P"2<'C'HGU30GC28G,B<E-,=Q$,>),C:03H>O9
M;DB)ZDB)ZTC!ZQM(P>(%2`G:B=))C1P43(GJ2,'B'DG![0)!B=Q(`XPD*`$`
M`$P)ZDV)W46)VTP#G"0P`0``23'51#'N38GE2(VT,:'KV6Y,B>%)P>T;2,'A
M!4P)Z8G)2`'Q2(GN2,'M`DC!YAY!B<](">Y(B=5-B?V)TD@Q]4G!Y05(`Y0D
M.`$``#'K28V<&Z'KV6Y-B?M)P>L;30GK3HTL&TR)XTG![`))B?-(P>,>1(GM
MB?9,">-),=M!B=Y$,=E-B>M)P>T;2<'C!4B-E`JAZ]EN08/E'TR)^4C!X1Y)
M(<-)P>\"30GK28G=20'33`GYNMR\&X]!B<])"<U%B=Q,(?M)(>U)"=U(BYPD
M0`$``$@!TT@!WDD!]4R)WDG!ZQM(P>8%08/C'T@AQDP)WDP![DF)[4C![0))
MP>4>B?-)">U,">E-B>M$B>U-(?M,(>%,"=E,BYPD2`$``$D!TTT!\TV)YDG!
M[`))`<M(B?%(P>X;2,'A!8/F'TG!YAY((<%("?%,B>Y,`=E-">9%B?1,"?9!
MB<M((=Y-(>5)"?5(B[0D4`$``$@!UDP!_DF)WTC!ZP))`?5(B<Y)P><>2,'F
M!4C!Z1M)"=]((<:#X1]-"?Y$B?M("<Y,B?E-(=Y,(>%,`>Y)"<Y(BXPD6`$`
M`$&)]4@!T4@!Z4D!SDB)\4C![AM(P>$%@^8?2"'!2`GQ3(G^3`'Q38G>2<'K
M`DG!YAZ)S4T)WD6)\TP)]DPA[DTAWTD)]TB+M"1@`0``2`'63`'F20'W2(G.
M2,'I&TC!Y@6#X1]((<9("<Y,`?Y-B>])P>T"2<'G'D&)]$T)[TT)_DR)^46)
M_4PAV4DA[DD)SDB+C"1H`0``2`'12`'920'.2(GQ2,'N&TC!X06#YA]((<%(
M"?%,B?Y,`?%)B>Y(P>T"2<'F'HG+20GN1(GU3`GV3"'F22'O20GW2(NT)'`!
M``!(`=9,`=Y)`?=(B<Y(P>D;2,'F!8/A'T@AQD@)SDP!_DV)YTG![`))P><>
M08GS30GG30G^3(GY18G\2"'I22'>20G.2(N,)'@!``!(`=%,`>E)B=U(P>L"
M20'.2(GQ2,'N&TC!X06#YA])P>4>2"'!2`GQ3(G^3`'Q20G=1(GK3`GN08G.
M3"'>22'?20GW2(NT)(`!``!(`=9(`>Y)`?=(B<Y(P>D;2,'F!8/A'T@AQD@)
MSDP!_DV)WTG!ZP))P><>B?5-"=]-"?U,B?E%B?M((=E-(?5)"<U(BXPDB`$`
M`$@!T4P!X4D!S4B)\4C![AM(P>$%@^8?2"'!2`GQ3(G^3`'I38GU2<'N`DG!
MY1Y!B<Q-"?5%B>Y,">Y((>Y-(?=)"?=(B[0DD`$``$@!UD@!WDD!]TB)SDC!
MZ1M(P>8%@^$?2"'&2`G.3`'^28GO2,'M`DG!YQZ)\TD)[TT)_4R)^42)_4PA
M\4TAY4D)S4B+C"28`0``2`'13`'920'-2(GQ2,'N&TC!X06#YA]((<%("?%,
MB?Y,`>E-B>5)P>P"2<'E'D&)RTT)Y46)[$P)[D@AWDTAYTD)]TB+M"2@`0``
M2`'63`'V20'W2(G.2,'I&TC!Y@6#X1]((<9("<Y,`?Y)B=](P>L"2<'G'D&)
M]DD)WTT)_4R)^42)^TPAX4TAW4D)S4B+C"2H`0``2`'12`'I3(G=2<'K`DD!
MS4B)\4C![AM(P>$%@^8?2,'E'D@AP4@)\4R)_DP!Z4P)W4&)ZT@)[D&)S4PA
M]DTAWTD)]TB+M"2P`0``2`'63`'F20'W2(G.2,'I&TC!Y@6#X1]((<9("<Y,
M`?Y-B?=)P>X"2<'G'D&)]$T)]TP)_4R)^46)_DPAV4PA[4@)S4B+C"2X`0``
M2`'12`'93(GK2<'M`D@!S4B)\4C![AM(P>$%@^8?2,'C'D@AP4@)\4R)_D@!
MZ4P)ZT&)W4@)WHG-3"'F32'O20GW2(NT),`!``!(`=9,`=Y-B>-)P>P"20'W
M2(G.2<'C'DC!Y@5(P>D;30GC2"'&@^$?3`G;18G<2`G.3(G92"'K3"'I3`'^
M2`G+2(N,),@!``!!B?=(`=%,`?%-B=Y(`<M(B?%(P>X;2,'A!8/F'T@AP4@)
M\4@!V4B)ZTC![0)(P>,>B<Y("=V)ZTD)[DTA_DDAVTT)\TR+M"30`0``20'6
M2`.4)-@!``!-`?5,`>)-`=U)B<M(P>D;2<'C!8/A'TDAPTP)V8G)3`'I38G]
M2<'O`DG!Y1Y!B<M-">]-B=Q,"?U-B?Y)P>P;18G]22'>2"'U3`GU3(NT).`!
M``!(`=5,B=I(P>(%3`GBB=)(`=5(B?)(P>X"2,'B'D&)[$@)UKK6P6+*23'W
M1#'Y20'63`'S38GF2`'+3(GA2<'N&TC!X05,"?&)R4@!RTR)V4G!ZP)(P>$>
M08G>20G+2(GQB?9,,=DQS4B+C"3H`0``2`'13`'I38GU2`'-3(GQ2<'M&TC!
MX05,">F)R4@!S4R)X4G![`)(P>$>08GM20G,2(N,)/`!``!(`=%(`?%,B=Y%
MB=M,,>8QWDR)ZT@!SDR)Z4C!ZQM(P>$%2`G9B<E(`<Y,B?%(P>$>2<'N`HGS
M20G.2(N,)/@!``!(`=%,`=E-B>-%B>1-,?-$,=U)B=M(`<U(B=E)P>L;2,'A
M!4P)V4R+G"0``@``B<E(`<U,B>E)`=-)P>T"2,'A'DT!XTV)]$&)[TP)Z46)
M]DDQS$0QYDV)_$D!\TR)_DG![!M(P>8%3`GF08GT2(G>2,'K`DC!YAY-`=Q)
MB<N)R4@)\TB+M"0(`@``18GE23';2`'61#'=38GK3`'V2`'U3(GN2,'F!4G!
MZQM,"=Y-B?M)P>\"B?9)P>,>2`'U2(NT)!`"``!-"?M!B>Y(`=9(`?%(B=Z)
MVTPQWD$Q]$R)]DD!S$R)\4C![AM(P>$%2`GQB<E)`<Q,B>E)P>T"2,'A'D6)
MYTD)S4B+C"08`@``3(G^2,'N&T@!T4@!V4R)VT6)VTPQZS'K2`'+3(GY2,'A
M!4@)\4R)]DG![@*)R4C!YAY(`<M(BXPD(`(``$P)]HG=2`'13`'938GK18GM
M23'S13'<28GK20',2(GI2<'K&TC!X05,"=E)B?.)]HG)20',3(GY2<'O`DC!
MX1Y%B>9)"<](BXPD*`(``$TQ^T@!T40QVTV)\TP!Z4G!ZQM(`<M,B?%(P>$%
M3`G93(N<)#`"``")R4@!RTB)Z4C![0))`=-(P>$>08G=3`'>2`GI3(G]38GK
M18G_2#'-2<'K&T0QY4@!]4R)[DC!Y@5,"=Y)B<N)R8GV2`'U3(GV2,'F'DG!
M[@)!B>Q)"?9(B[0D.`(``$TQ\T@!UD0QVTV)XTP!_DG!ZQM(`?-,B>9(P>8%
M3`G>38GK2<'M`HGV2<'C'D@!\TB+M"1``@``30GK08G?2`'62`'Q3(GV18GV
M3#'>,?5,B?Y(`<U,B?E(P>X;2,'A!4@)\4R)WD6)VXG)2`'-3(GA2<'L`DC!
MX1Y!B>U)"<Q(BXPD2`(``$PQYD@!T3'S3(GN3`'Q2`'+3(GI2,'A!4C![AM(
M"?%,B?Y)P>\"B<E(P>8>2`'+2(N,)%`"``!,"?Y!B=Y(`=%,`=E-B>-%B>1)
M,?-!,>M,B?5)`<M,B?%(P>T;2,'A!4@)Z8G)20'+3(GI2<'M`DC!X1Y$B=U)
M"<U(BXPD6`(``$@!T4P!X4F)](GV33'L1#'C28GL2`'+2(GI2<'L&TC!X05,
M">&)R4@!RTR)\4G![@)(P>$>08G<3`GQ3(NT)&`"``!)`=9,`?9-B>Y%B>U)
M,<Y%,?--B>9,`=Y-B>-)P>X;2<'C!4T)\TF)[DC![0))P>8>18G;3`GU3(NT
M)&@"``!,`=Y!B?-)`=9-`?5)B<Z)R4DQ[D0Q\TV)WDP!ZTV)W4G![AM)P>4%
M30GU38GF2<'L`DG!YAY%B>U-"?1,B[0D<`(``$P!ZT&)W4D!UDP!\4F)[HGM
M33'F1#'V38GN2`'.3(GI2<'N&TC!X05,"?%(`?%,B=Y(P>8>2<'K`D@#E"1X
M`@``20GS3(GF3`'"1`-G($PQWD@!ZD4!VDR)9R`Q\TB)SDR)5QA(P>8%2`':
M2"'P2(G.`T\(2,'N&TB)3PB#YA]("?`!T$B)!TR)Z$G![0)(P>`>20G%10'I
M3(E/$$B+A"2(`@``9$@S!"4H````=1)(@<28`@``6UU!7$%=05Y!7\/H#.7_
M_V9F+@\?A```````D$%7059!54%455-(@^P(2(7_#X2Q````3(LU8H(``$V%
M]@^$H0````^V!TF)_TB)]83`=`0\/75813'M38LF387D=#--8^U,B?,/'X``
M````3(GJ3(G^3(GGZ,+B__^%P'4'0X`\+#UT1TR+8PA(@\,(387D==I(@\0(
M3(G@6UU!7$%=05Y!7\,/'X0``````$F)_4$/MD4!28/%`83`=`0\/77O12G]
MZY(/'X``````3"GS3XUD+`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!54TB)
M^TB#[!AD2(L$)2@```!(B40D"#'`2(UL)`1FD#'`2(GN2(G?Z`/___](A<!T
M-DAC5"0$2(L%<H$``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72
M=?#KOF8/'T0``$B+1"0(9$@S!"4H````=0=(@\086UW#Z*SC__]F9BX/'X0`
M`````)!!5T%6055!5%5(B?532(G[2(/L*&1(BP0E*````$B)1"08,<`QP(`^
M/0^4P$@!Q4B)[^A9XO__2(UT)!1(B=])B<0QP.A7_O__2(7`#X0.`0``2(G'
M28G%Z#/B__],.>`/@]H```!,8W0D%$G!Y@,/M@.$P`^$K@$``#P]#X2F`0``
M2(G8#Q\`#[90`4B#P`&$TG0%@/H]=>](*=A(F$J-?"`"3`,U=H```.@AX?__
M28D&2(7`#X2&`0``2(L%7H```$AC5"042(U+`4B+%-`/M@.(`CP]=!V$P'4(
MZQ=FD#P]=!$/M@%(@\(!2(/!`8@"A,!UZ\8"/3'`9@\?1```#[9,!0"(3`(!
M2(/``83)=>\QP$B+7"089$@S'"4H````#X45`0``2(/$*%M=05Q!74%>05_#
M9BX/'X0``````#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[4/'T``3(L]
MN7\``$F#/P`/A+X```!,B?A%,>UF#Q^$``````!(@\`(1(GJ08/%`4B#.`!U
M[XUR`TAC]DC!Y@.+!=^/``"%P'5;QP71CP```0```$B)]^@9X/__2(7`#X2!
M````36/%3(G^2(G'3HTTQ0````!,B40D"$R)\NA2X?__3(M$)`A(B04V?P``
M2(G!2L=$P0@`````1(EL)!3I;_[__TR)_^A(XO__2(D%$7\``$B)P4B%P'0J
M36/%3HTTQ0````#KR0\?0``QP.EO_O__OA````!%,>WI7____^A?X?__@\C_
MZ<K^__\/'X``````059!54%455-(@>R@````9$B+!"4H````2(F$))@````Q
MP$B%_W0(@#\`2(G]=3%(BX0DF````&1(,P0E*`````^%$0$``$B!Q*````!;
M74%<05U!7L-F+@\?A```````Z.O?__])B<1(A<!TPDB)XTR)Y^C(X?__2(7`
M#X2G````9H-X$RY,C7`3=.1F@7@3+BX/A*@```!(B>_HH-___TR)]TF)Q>B5
MW___08U\!0)(8__HR-[__TV)\4F)Z+X!````28G%2(G',<!(Q\+_____2(T-
MOAT``.@"X?__OP$```!(B=I,B>[HLN#__TR)[X/X_W00BT0D&"4`\```/0!`
M``!T2NBUWO__3(GOZ!W?__],B>?H)>'__TB%P`^%7?___P\?0`!,B>?HH.#_
M_TB)[^B8WO__Z?+^__\/'P!!@'X"``^$)?___^E(____Z*O^___KM.CTW___
M#Q]``%5(B?Y(B?V_`0```$B![*````!D2(L$)2@```!(B80DF````#'`2(GB
MZ'+?__^%P'4VBU0D&('B`/```('Z`$```'0(@?H`H```=1Z^`@```$B)[^@W
MX/__A<`/E,`/ML#K!P\?1```,<!(BXPDF````&1(,PPE*````'4)2('$H```
M`%W#Z&7?__\/'T0``$%7NO\/``!!5D%5051)B?152(G]2(T]DAP``$B![!`0
M``!D2(L$)2@```!(B80D"!```#'`28GE3(GNZ)#>__^%P'YTC5#_1(L]<GP`
M`$QC\D*`/#0`=5B%TG1C3(GROB\```!,B>_HQ-S__TB%P'1.1(G_Z%?<__],
MB?%,B>I(B>Y(B<?H-M[__TB+A"0($```9$@S!"4H````=3I(@<00$```74%<
M05U!7D%?PV:03&/PZZ</'P!$BST!?```1(G_Z`G<__],B>)(B>Y(B<?H&]W_
M_^NSZ(3>__\/'T``2(/L"(L]UGL``.CAV___2(L5FGL``$B#Q`A(C0V_6@``
M2(G'2(TUL1L``.D0W___2(/L"(L]IGL``.BQV___2(G'Z+G___^+/9-[``#H
MGMO__TR-!1@=``!%,<E(C16-$@``2(G'3(G!2(TUB!L``$B#Q`CI)]W__P\?
M@`````!!5%532('L("```&1(BP0E*````$B)A"08(```,<!(B>5,C:0D$!``
M`.B"W/__3(T-(QL``+H!$```2(GO08G`2(T-1AL``+X!````,<#H/=[__[H`
M$```3(GF2(GOZ`W=__]%,<"%P'@NC7@!2(G#2&/_Z+C;__])B<!(A<!T&$AC
MVTR)YDB)QTB)VNA/WO__Q@08`$F)P$B+A"08(```9$@S!"4H````=0](@<0@
M(```3(G`6UU!7,/H0=W__Y#I.____V9F+@\?A```````05=!5DF)]D%5051)
MB?Q(C3VT&@``55-(@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z/7W
M__^^+P```$R)YTB)Q>B%W/__2(7`=$!,B>9(C3UX&@``,<#H+_G__TR)X$B+
MC"2H$```9$@S#"4H````#X5R`0``2('$N!```%M=05Q!74%>05_##Q\`3(GG
MZ(C;__](C35`&@``3(GW08G%Z*;<__](B<-(A<!TGH`[`$R--;D9```/A-4`
M``!F#Q]$``!(A>UT$TB)WDB)[^AHW/__A<`/A)0```!(B=_H.-O__XG"2)B`
M?`/_+W46#Q]$``"#Z@%(8\*`?`/_+\8$`P!T[T&-1!4!/?\/```/CS?___])
MB=BZ`!```+X!````,<!,C;PDH````$B#[`A(C0V<&@``051,C0V=&0``3(G_
MZ'3<__](C50D($R)_K\!````Z"+<__]:687`=1"+1"0H)0#P```]`(```'1,
M2(TU9!D``#'_Z,[;__](B<-(A<`/A,+^__^`.P`/A3'___](A>UT!H!]`"YT
M#DR)\[H!````Z5K___^0@'T!`'2^Z^H/'X0``````+X!````3(G_Z`/<__^%
MP'6C3(G^2(T]]Q@``.BP]___3(G_Z"C;___I=_[__^@^V___9F8N#Q^$````
M```/'P`/M@=)B?B$P'079@\?1```2(/'`3PO#[8'3`]$QX3`=>],B<##9F8N
M#Q^$``````!(A?\/A,<```!5@#\`2(G]#X2B````Z-79__](C50%_T@YU7(4
MZ9L```!F#Q]$``!(@^H!2#G5="6`.B]T\D@YU0^#?@```$B#Z@%(.=5T#H`Z
M+W0@2(/J`4@YU77R@#HO=%5(C3U'&```7>EPVO__@#HO=0E(@^H!2#G5<O)(
M*>HQP$B-2@)(@?D`$```=Q](@\(!N0`0``!(B>Y(C3T]>```Z/C7__](C04Q
M>```7<,/'X``````2(T]AA<``%WI&]K__T@YU76KZY(/'T``2(T];A<``.D$
MVO__#Q]``%4QTDB-/<D7``!(@^Q`9@]O!7I6``!D2(L$)2@```!(B40D.#'`
M9HE4)#!(C6PD#`\I1"009@]O!6-6```/*40D(.BI]?__,<!(C3V,%P``Z)OU
M__\QP$B-/887``#HC?7__S'`2(T]@1<``.A_]?__,<!(C3UZ%P``Z''U__\Q
MP$B-/7P7``#H8_7__S'`2(T](Q<``.A5]?__,<!(C3UL%P``Z$?U__\QP$B-
M/6@7``#H.?7__S'`2(T]9!<``.@K]?__,<!(C3WT%@``Z!WU__\QP$B)[DB-
M/4\7``#H//3__TB%P'012(G&2(T])Q<``#'`Z(;U__](B>Y(C3T[%P``,<#H
M%?3__TB)QDB%P'0.2(T]-Q<``#'`Z%_U__](B>Y(C3TQ%P``,<#H[O/__TB)
MQDB%P'0^2(T]>!8``#'`Z#CU__\QP$B--3<7``!(C3V<%@``Z"/U__](BT0D
M.&1(,P0E*````'5<2(/$0%W##Q]$``!(B>Y(C3WJ%@``,<#HE_/__TB)QDB%
MP'072(T]>!8``#'`Z.'T___KIP\?@`````!(N%!!4E]#3$5!2#E$)"%UCV:!
M?"0I3CUUADB-="0KZ\CH4MC__V:02(/L&&1(BP0E*````$B)1"0(,<"+!89U
M``"#^/]T&4B+?"0(9$@S/"4H````=4!(@\08PP\?0`!(C70D!$B-/?P5```Q
MP.@%\___2(G",<!(A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(D%,W4``.NPZ-S7
M__]F9BX/'X0``````)!(@^P(Z/?7__^)Q^B`UO__2(7`=`-(BP!(@\0(PP\?
M`$%454B)_4B-/0T6``!32(/L$&1(BP0E*````$B)1"0(,<!(C70D!.B$\O__
M2(GN2(7`=`B`.`!(B<-U+$B-/=<5```QP.C&\___2(M$)`AD2#,$)2@```!U
M?TB#Q!!;74%<PP\?1```2(G'Z)#6__](A<!UU4B)[^@CUO__2(G?28G$Z!C6
M__])C7P$`NA.U?__2(/L"$F)Z+X!````4TC'PO____](B<=)B<1,C0VL%```
M2(T-G14``#'`Z'_7__],B>9(C3U/%0``,<#H/O/__UA:Z7'____HTM;__V:0
M05=)B?](C3U=%```059!54%455-(@>R8@0``9$B+!"4H````2(F$)(B!```Q
MP$B-!2$5``!,C6PD+$C'1"1``````$B)1"0P2(T%QA,``$R)[DB)1"0X2(T%
MG!0``$B)1"1X2(T%\10``$B)A"2`````2(T%GA0``$B)A"2(````2(T%VQ0`
M`$B)A"20````2(T%T!0``$B)1"18,<!(QX0DF`````````!(QT0D8`````#H
M&/'__TB%P'0,@#@`2(G%#X7W!```,<#H,/[__TB)Q4B%P`^$1`0``$B)[^C<
MU/__2(U\``'H$M3__T0/MD4`2(G#183`=#A)B=Y,C25K%```#Q\`3(GW3(GA
M2,?"_____S'`O@$```!(@\4!28/&`N@WUO__1`^V10!%A,!UU4R-9"1P2(T]
MPA,``.L9#Q^``````$F+?"0(28/$"$B%_P^$E@$``$R)[C'`Z&SP__](B<5(
MA<!TW(`X`'372(G'Z&?U__^%P'3+2(GOZ"O5__])B<9(A<`/A%\!```/'X``
M````3(GQBQ%(@\$$C8+__O[^]](AT"6`@("`=.F)PL'J$*F`@```#T3"2(U1
M`D@/1,J)P@#"2(G:2(/9`TPI\8LR2(/"!(V&__[^_O?6(?`E@("`@'3IB<;!
M[A"I@(````]$QDB-<@)(#T36B<9``,9(@]H#2"G:1(VD$00$``!-8^1,B>?H
MX-+__U-,C0U9$@``38GP2(G%2(T%21,``+X!````2,?"_____U!(C0TL$P``
M2(GO,<#H#=7__[[``0``2(GOZ'#5__]!6$%9@_C_=1+H,M3__T2+"$&#^1$/
MA1D#``!,C;0DH````$B)[K\!````3(GRZ.W3__^)PX7`#X2S````28L/2(L]
MR7$``$F)Z#'`2(T5?1,``+X!````13'DZ/#1__](BX0DB($``&1(,P0E*```
M``^%7`@``$B!Q)B!``!,B>!;74%<05U!7D%?PP\?0`!(BVPD,$4QY.L39@\?
M1```26/$2(MLQ#!(A>UT.X!]``!T-4B)[T&#Q`'HP?/__X7`=-U(B>_HA=/_
M_TF)QDB%P`^%8?[__TECQ$B+;,0P2(7M=<D/'T``13'VZ4C^__^+A"2X````
M)0#P```]`$````^%-O___XN$)+P```")!"3HBM/__SD$)`^%'O___XN$)+@`
M```E_P$``#W``0``#X4'____3(GGZ&+1__](C3V@$0``3(GN28G$,<#H'N[_
M_TB)QTB%P`^$(@(``.CMTO__28L_2(G&Z-+U__])B<5(A<`/A`8"``!,B>_H
MWM'__X/X`WY!2&/0N04```!(C3V-$0``28UT%?SSI@^7PH#:`(32=2&#^`0/
MA-`%``"#Z`1(F$&`?`7_+P^$OP4```\?@``````QP.A1^O__A<!U%3'V3(GO
MZ-/1__]!B<>%P`^%H`$``$B-->D0``!(C3UJ$```,<#HT^[__TR-+5T1``!,
MC346$```Z!#1__]!54F)Z+X!````4$C'PO____],B><QP$R-#?,/``!(C0T'
M$0``Z,;2__]86NM#9I#H^]'__X,X$75)Z-'0__^#PP%(@^P(38GQ055)B>A(
MC0WE$```3(GG4TC'PO____^^`0```%`QP.B#TO__2(/$(+[``0``3(GGZ.+2
M__^#^/]TK4B)[^BUT/__3(GF2(T]9`\``#'`Z"3N__],B>?H#/K__^FG_?__
M#Q^``````$B-/2,0```QV^L2#Q]$``!(8\-(BWS$4$B%_W0X3(GN,<"#PP'H
MANS__TB%P'3A@#@`=-Q(B<?H5-'__TB)Q4B%P`^%=/O__TACPTB+?,102(7_
M=<B_#0```$B-+<X/``#H>L___T&X4P```$B)P^EG^___28L/2(L]TFX``$F)
MZ#'`2(T51A```+X!````13'DZ/G.___I!/W__P\?0`!(B<?H6/G__TB)[^C@
MT/__28G$Z>C\__\/'X0``````$V++^GR_?__N@(```!(Q\;N____B<?H1='_
M_TB-A"2``0``N@8```!$B?](B<9(B00DZ,G.__^`O"2``0```'4.@+PD@0$`
M`$,/A(,$```QTC'V1(G_Z`71__^XB:O-[TC'A"2@`````2-%9TB)A"2H````
M2"V+SA)72(F$)+````!(!?($&"M(B80DP````$B-A"38````2,>$)+@```!V
M5#(02,>$),@`````````2,>$)-``````````QX0D&`$```````!(B40D&`\?
M0`!(BS0DN@"```!$B?_H'\[__TB)P4&)P(7`#XY=`0``2(N\),@```!(BY0D
MT````$ACP4B+'"2--,](.?Y(B;0DR````$B#T@!(P>@=2`'02&.4)!@!``!(
MB80DT````(72#X6I````08/X/P^.`0,``$&-0,")1"04P>@&08G%B40D"$F#
MQ0%)P>4&20'=9I#S#V\+\P]O4Q!,B?=(@\-`\P]O6^#S#V]C\`\1C"38````
M#Q&4).@````/$9PD^`````\1I"0(`0``Z('3__],.>MUO(M$)`A$BT0D%,'@
M!D$IP$B+?"0826/0N4@```!,B>Y$B40D".C#S?__1(M$)`A$B80D&`$``.GQ
M_O__D$&X0````$B+1"082(LT)$B)3"0(02G01#G!2(T\$$0/3L%)8]A(B=KH
MP\___XN$)!@!``!(BTPD"`'8@_A`B80D&`$```^%I?[__T&)R$R)]T$IV$@#
M'"1$B40D".C>TO__1(M$)`CIZ_[__T2)_^A,S/__2(N$),@```"+G"3(````
M1(NL)-````!(P>@##\N#X#]!#\V-2`%(F,:$!-@```"`@_DX#XZ]`0``ND``
M``!(8_%(`W0D&"G*=`\QP(G!@\`!Q@0.`#G0<O-,B??H:]+__V8/[\!(QX0D
M"`$````````/$80DV`````\1A"3H````#Q&$)/@```!,B?=$B:PD$`$``$R-
MO"0Q`0``3(VT)'@!``")G"04`0``3(TMB@P``.@5TO__2(N$)*`````/MY0D
MH````$F)P$C!Z!"(A"0Q`0``9L'""$G!Z!B+A"2H````9HF4)#(!```/R(F$
M)#0!``"+A"2P````#\B)A"0X`0``BX0DN`````_(B80D/`$``(N$),`````/
MR(F$)$`!``!(C80D4`$``$B)!"1(B</K#F8/'T0``$4/M@=)@\<!2(G?10^V
MP$R)Z;X!````2,?"_____S'`2(/#`NC'S?__23G>==)(C04<#```QH0D>`$`
M``!0_W0D"$B-#=0+``!)B>A,B><QP+X!````3(T-M`H``$C'PO_____HA\W_
M_UE>Z1/[__]-BW\(387_#X0[^O__3(G_Z,O+__](@_@##X8I^O__28UT!_RY
M!0```$B-/7@+``#SI@^7P!P`A,!-#T3OZ0;Z__])B=WI:?W__[HX````2&/!
M,?](`T0D&"G*@_H(<S#VP@0/A=<```"%T@^$;/[__\8``/;"`@^$8/[__S'_
M9HE\$/[I5/[__P\?@`````")T4C'``````!(QT0(^`````!(C4@(2(/A^$@I
MR`'0@^#X@_@(#X(B_O__@^#X,=*)UH/""$B)/#$YPG+SZ0O^__^`O"2"`0``
M00^%;_O__X"\)(,!``!##X5A^___@+PDA`$``$@/A5/[__^`O"2%`0``10^%
M1?O__[H"````2,?&QO___T2)_^A"S/__2(L<)+HI````1(G_2(G>Z,[)__](
MC06H"@``4%/IDO[__\<``````,=$$/P`````Z8K]___HF,O__P\?A```````
M05=!5D%505154TB#[!B+/=QH``!D2(L$)2@```!(B40D"#'`3(UL)`3HTLC_
M_XL]O&@``$B)P^C$R/__#[:3N````$R)[DB-/1<)``"(D+D````QP.@VYO__
M2(7`=`F`.#$/A/@"```QP.@!\?__BSU[:```Z(;(__^Y"P```+H!````2(TU
M\`D``$B)Q^A=R?__1(LU5F@``$B%P`^$S0```$B+0!"#/=)X```!3(M@*`^.
MN````#';ZS8/'T``28MW$$B+!:UX``!(8]5(BSS0Z,G*__]!B<"+!:!X``!%
MA<`/A7P```"#PP(YPXGK?7-$B?>-:P'H`\C__S')2&/33(GF2(G'Z`/*__](
MA<!T1DR+.$2+-=1G``!!BT<,)0`$(``]``0``'241(GWZ,S'__],B?ZY`@``
M`#'22(G'Z%K+__]$BS6C9P``2(G&Z6____\/'P"+!2)X``!$BS6+9P``C5#_
M.=H/A(`!``!$B??HB,?__[D#````N@$```!(C37W"```2(G'Z%_(__](B<-(
MA<!T-4B+0!"+/4UG``!(BRCH5<?__TB-%=`(``!(B<=(B>[H8\C__TB+0Q!(
MBRCV10Y`#X7.`0``BST<9P``Z"?'__^Y`P```+H!````2(TUG0@``$B)Q^C^
MQ___2(G#2(7`=#U,B>Y(C3TN!P``,<#HA>3__TF)Q$B%P`^$60$``$B+0Q"+
M/<]F``!(BRCHU\;__TR)XDB)QTB)[NCIQ___BSVS9@``Z+[&__^Z`0```$B-
M-3L(``!(B<?HRL;__XL]E&8``$B)Q>B<QO__2(T5,P@``$B)[DB)Q^BJQ___
MBSUT9@``Z'_&__],B>Y(C3V>!@``QH"Y`````#'`Z/?C__](B07H=@``28G$
M2(7`#X2$````OL`!``!,B>?HU\G__XU0`8/Z`78)@_@1#X7R````2(M$)`AD
M2#,$)2@````/A=D```!(@\086UU!7$%=05Y!7\,/'P"#^`$/CG?^__^[`0``
M`&:01(GW@\,!Z/7%__],B>9(B<?HRL;__SD=9'8``$2+-<UE``!_V^E&_O__
M9@\?1```2(L]078``.B$\?__2(D%178``$F)Q$B%P`^%7?___TB-/?('```Q
MP.ASR/__#Q\`@'@!``^$!?W__^GY_/__D$B+!0%V``"+/7-E``!,BR!(BT,0
M2(LHZ'3%__],B>9(B>_HF>C__^F;_O__BSU.90``Z%G%__](B>Y(B<?HSL?_
M_^D7_O__Z-3'__^)P4B+!;-U``!,B>)(C3VA!P``2(LP,<#H]\?__P\?@```
M``!52(G]4TB#[`CHHNS__P^V$$B)PX32=!H/'X0``````$B#P`&`^B\/MA!(
M#T38A-)U[C'`Z"?O__](A>UT)(7`=""`?0``=!JY!````$B-/0H&``!(B=[S
MI@^7P!P`A,!T!TB#Q`A;7<-(@\0(2(GO6UWIZ>7__V8/'X0``````$%73(T]
M%V```$%628G6055)B?5!5$&)_%5(C2T(8```4TPI_4B#[`CH0\3__TC!_0-T
M&S';#Q\`3(GR3(GN1(GG0?\4WTB#PP%(.=UUZDB#Q`A;74%<05U!7D%?PP\?
M`,-F+@\?A```````#Q]$``!(BPT!9```Z;3$__](@^P(2(/$",,`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P
M,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E
M<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2
M.CI086-K97(Z.E9%4E-)3TX`,2XP-#<`+64`+2T`````````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G
M"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP
M+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP
M.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF
M:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@
M-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ
M92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O
M<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@
M)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@
M)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL
M87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S
M970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@
M)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O
M9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S
M970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T
M.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I
M;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U
M-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA
M;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY
M("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N
M;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@
M<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M
M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP
M;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL
M96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM
M;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N
M;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I
M92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@
M82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V
M86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD
M968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E
M7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@
M)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N
M86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA
M;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?
M.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI
M('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H
M;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T
M96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG
M("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N
M+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F
M:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)
M3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF
M("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX
M?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N
M(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P
M<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N
M86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C
M='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C
M:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M
M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z
M("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T
M<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*
M*%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R
M;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K
M("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@
M<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L
M(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%2
M7T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\[
M"FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE
M("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*
M;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I
M=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O
M;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@
M9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O
M<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U
M8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G
M;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]4
M14U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@
M,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R
M;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R
M7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.
M?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS
M=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I
M;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*
M<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL
M:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O
M<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?
M14Y$7U\*``````!P97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("`!&P,[[````!P```#0@/__.`$``)"$__]@`0``H(3_
M_R0&``"PAO__"`$``*"'__]X`0``<)[__\@!``!`G___%`(``-"?__]``@``
M(*+__XP"``"`H___T`(``!"D___T`@``\*3__S@#```@I?__4`,``'"E__]H
M`P``,*;__YP#``!`IO__L`,``$"H__\0!```<*C__R0$``!0J?__5`0``""K
M__]X!```H*O__Y0$``#`J___K`0``*"L___L!```X+?__Z0%``#`N___\`4`
M`$"\__]0!@``H+S__Y@&``"PO/__L`8````````4``````````%Z4@`!>!`!
M&PP'")`!!Q`4````'````*"%__\K```````````````4``````````%Z4@`!
M>!`!&PP'")`!```D````'````)!____``P````X01@X82@\+=PB``#\:.RHS
M)"(`````%````$0````H@___"```````````````3````%P````@AO__Q!8`
M``!"#A"/`D8.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`Y\6"@XX00XP
M00XH0@X@0@X80@X00@X(00L```!(````K````*"<___-`````$(.$(\"0@X8
MC@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X0
M0@X(20L`*````/@````DG?__A`````!!#A"&`D$.&(,#1PXP`G,*#AA!#A!!
M#@A!"P!(````)`$``(B=__])`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9$#CB#!T<.8`,7`0H..$$.,$$.*$(.($(.&$(.$$(."$L+0````'`!``",
MG___7`$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`7X*#C!!#BA!
M#B!"#AA"#A!"#@A+"P`@````M`$``*B@__^+`````$$.$(8"4@ZP`0)Q"@X0
M00X(00M`````V`$``!2A___<`````$(.$(\"1PX8C@-"#B"-!$(.*(P%1`XP
MA@91#L`@`H(*#C!!#BA"#B!"#AA"#A!"#@A#"Q0````<`@``L*'__S``````
M1`X05@X(`!0````T`@``R*'__TD`````1`X0`D`."#````!,`@```*+__[\`
M````0@X0C`)!#AB&`T$.((,$1P[`0`*G"@X@1`X800X00@X(00L0````@`(`
M`(RB__\%`````````%P```"4`@``B*+___(!````0@X0CP)"#AB.`T4.((T$
M0@XHC`5+#C"&!D$..(,'1P[P(0)D"@XX00XP00XH0@X@0@X80@X00@X(1`L"
MI`[X(4D.@")B#O@A00[P(0```!````#T`@``**3__R4`````````+`````@#
M``!$I/__W`````!*#A"&`@)A"L8."$4+`D`*#@A("T@*Q@X(10M+#@C&(```
M`#@#``#TI/__S@$```!!#A"&`DT.4`-C`0H.$$$."$8+&````%P#``"@IO__
M=`````!$#B!O"@X(10L``!0```!X`P``!*?__QT`````1`X06`X(`#P```"0
M`P``#*?__]X`````0@X0C`)!#AB&`TL.((,$1`XP`DP*#B!!#AA!#A!"#@A&
M"VX..$D.0'0..$$.,`"T````T`,``*RG__\X"P```$(.$(\"3`X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T<.T(,"`P8"#MB#`F$.X(,"8`[8@P)"#M"#`@)Z
M"@XX1`XP00XH0@X@0@X80@X00@X(10L#@@$.V(,"20[@@P)@#MB#`D$.T(,"
M6@[8@P)%#N"#`DX.Z(,"30[P@P)+#M"#`@/-!`[8@P)$#N"#`F@.V(,"00[0
M@P(#/P$*#MB#`D$.X(,"10L`2````(@$```TLO__V0,```!"#A"/`D(.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P=$#E`#U`(*#CA!#C!!#BA"#B!"#AA"#A!"
M#@A$"S````#4!```R+7__W<`````00X0A@)$#AB#`T0.(`)="@X800X000X(
M00M$#AA$#A!!#@@H````"`4``'1^__\$`@```$(.$(P"00X8A@-$#E`#HP$*
M#AA$#A!"#@A!"T0````T!0``Z+7__UT`````0@X0CP))#AB.`T4.((T$10XH
MC`5$#C"&!D@..(,'1PY`:@XX00XP00XH0@X@0@X80@X00@X(`!0```!\!0``
M`+;__P$``````````````!````"4!0``^+7__PP`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#@)@```````*`F````
M`````0`````````!``````````$`````````O`$````````!``````````L"
M````````#```````````(`````````T`````````#%P````````9````````
M`+"[````````&P`````````(`````````!H`````````N+L````````<````
M``````@`````````]?[_;P`````(`P````````4`````````*`T````````&
M`````````/@#````````"@````````"Z!`````````L`````````&```````
M```5`````````````````````P````````#0O0````````(`````````B`4`
M```````4``````````<`````````%P````````"H%`````````<`````````
M*!,````````(`````````(`!````````"0`````````8`````````!X`````
M````"`````````#[__]O``````$```@`````_O__;P````"H$@```````/__
M_V\``````@````````#P__]O`````.(1````````^?__;P`````$````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````P+L`````````
M````````````````````-B````````!&(````````%8@````````9B``````
M``!V(````````(8@````````EB````````"F(````````+8@````````QB``
M``````#6(````````.8@````````]B`````````&(0```````!8A````````
M)B$````````V(0```````$8A````````5B$```````!F(0```````'8A````
M````AB$```````"6(0```````*8A````````MB$```````#&(0```````-8A
M````````YB$```````#V(0````````8B````````%B(````````F(@``````
M`#8B````````1B(```````!6(@```````&8B````````=B(```````"&(@``
M`````)8B````````IB(```````"V(@```````,8B````````UB(```````#F
M(@```````/8B````````!B,````````6(P```````"8C````````-B,`````
M``!&(P```````%8C````````9B,```````!V(P```````(8C````````EB,`
M``````"F(P```````+8C````````QB,```````#6(P``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#H8@```````$=#
M0SH@*$1E8FEA;B`Y+C(N,2TX*2`Y+C(N,2`R,#$Y,#DP.0``+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X
M=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET
M7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE
M;G0`````````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"`````````*@"
M````````J`(````````<`````````````````````0``````````````````
M`!,````'`````@````````#$`@```````,0"````````)```````````````
M``````0````````````````````F````!P````(`````````Z`(```````#H
M`@```````"`````````````````````$````````````````````-````/;_
M_V\"``````````@#````````"`,```````#P``````````4`````````"```
M`````````````````#X````+`````@````````#X`P```````/@#````````
M,`D````````&`````0````@`````````&`````````!&`````P````(`````
M````*`T````````H#0```````+H$```````````````````!````````````
M````````3@```/___V\"`````````.(1````````XA$```````#$````````
M``4``````````@`````````"`````````%L```#^__]O`@````````"H$@``
M`````*@2````````@``````````&`````@````@```````````````````!J
M````!`````(`````````*!,````````H$P```````(`!````````!0``````
M```(`````````!@`````````=`````0```!"`````````*@4````````J!0`
M``````"(!0````````4````6````"``````````8`````````'X````!````
M!@``````````(``````````@````````%P````````````````````0`````
M``````````````!Y`````0````8`````````("`````````@(````````,`#
M```````````````````0`````````!``````````A`````$````&````````
M`.`C````````X",````````(````````````````````"``````````(````
M`````(T````!````!@````````#P(P```````/`C````````'#@`````````
M`````````!````````````````````"3`````0````8`````````#%P`````
M```,7`````````D````````````````````$````````````````````F0``
M``$````"``````````!@`````````&````````!0/P``````````````````
M$````````````````````*$````!`````@````````!0GP```````%"?````
M````[`````````````````````0```````````````````"O`````0````(`
M````````0*````````!`H````````-@%```````````````````(````````
M````````````N0````X````#`````````+"[````````L*L````````(````
M````````````````"``````````(`````````,4````/`````P````````"X
MNP```````+BK````````"`````````````````````@`````````"```````
M``#1````!@````,`````````P+L```````#`JP```````!`"````````!@``
M```````(`````````!``````````B`````$````#`````````-"]````````
MT*T````````P`@``````````````````"``````````(`````````-H````!
M`````P``````````P`````````"P````````(`````````````````````@`
M``````````````````#@````"`````,`````````(,`````````@L```````
M`*@0```````````````````@````````````````````Y0````$````P````
M````````````````(+`````````E`````````````````````0`````````!
M``````````$````#`````````````````````````$6P````````[@``````
:``````````````$`````````````````````
